<?php
if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {

    class Smsbox_config extends WC_Order{
        /**
         * Constructor
         */
        function __construct() {

            // Triggers for this
            add_action( 'woocommerce_order_status_changed', array( $this, 'trigger' ));
            add_action('woocommerce_created_customer', array( $this, 'trigger_new_customer' ));

            // Call parent constructor
            parent::__construct();
        }
        /**
         * Trigger.
         */
        function trigger($order_id) {

            if(get_credits() > 0){

                $order = wc_get_order( $order_id );
                $products = $order->get_items();
                $product_id = '';
                $product_name = '';
                $product_qty = '';
                foreach ($products as $key => $products) {
                    $product_id .= $products['product_id'].',';
                    $product_name .= $products['name'].',';
                    $product_qty .= $products['qty'].',';
                }
                $smsbox_config = get_option('wp_smsbox_config');
                if($smsbox_config['order_status']['customer'][$order->get_status()]){

                    // send to customer
                    if ($smsbox_config['notify_customer'] == '1' && intval($smsbox_config['notify_customer'])) {

                        // get correct message based on checkbox selection
                        if($order->get_status() == 'on-hold') {
                            $sms_customer_message =  $smsbox_config['customer_message_onhold'];
                        }
                        elseif($order->get_status() == 'pending') {
                            $sms_customer_message =  $smsbox_config['customer_message_pending'];
                        }
                        elseif($order->get_status() == 'processing') {
                            $sms_customer_message =  $smsbox_config['customer_message_processing'];
                        }
                        elseif($order->get_status() == 'completed') {
                            $sms_customer_message =  $smsbox_config['customer_message_completed'];
                        }
                        elseif($order->get_status() == 'cancelled') {
                            $sms_customer_message =  $smsbox_config['customer_message_cancelled'];
                        }
                        elseif($order->get_status() == 'refunded') {
                            $sms_customer_message =  $smsbox_config['customer_message_refunded'];
                        }
                        elseif($order->get_status() == 'failed') {
                            $sms_customer_message =  $smsbox_config['customer_message_failed'];
                        }

                        $costumer_template = str_replace(array('[billing_first_name]','[billing_last_name]','[order_id]', '[order_status]', '[order_date]', '[payment_method]', '[payment_total]', '[product_id]', '[product_name]', '[product_qty]'), array($order->billing_first_name,$order->billing_last_name,$order->id, str_replace('wc-', '', $order->post_status), $order->order_date, $order->payment_method_title, html_entity_decode (strip_tags($order->get_formatted_order_total())), trim($product_id, ','), trim($product_name, ','), trim($product_qty, ',')), $sms_customer_message);
                        $to_costumer = array();
                        $to_costumer['type'] = 'customer';
                        $to_costumer['to'] = $order->billing_phone;
                        $to_costumer['message'] = $costumer_template;
                        $this->sendVsms($to_costumer);
                    }
                }
                if($smsbox_config['order_status']['admin'][$order->get_status()]){

                    // send to admin
                    if ($smsbox_config['notify_admin'] == '1' && intval($smsbox_config['notify_admin'])) {

                        // get correct message based on checkbox selection
                        if($order->get_status() == 'on-hold') {
                           $sms_admin_message =  $smsbox_config['admin_message_onhold'];
                        }
                        elseif($order->get_status() == 'pending') {
                            $sms_admin_message =  $smsbox_config['admin_message_pending'];
                        }
                        elseif($order->get_status() == 'processing') {
                            $sms_admin_message =  $smsbox_config['admin_message_processing'];
                        }
                        elseif($order->get_status() == 'completed') {
                            $sms_admin_message =  $smsbox_config['admin_message_completed'];
                        }
                        elseif($order->get_status() == 'cancelled') {
                            $sms_admin_message =  $smsbox_config['admin_message_cancelled'];
                        }
                        elseif($order->get_status() == 'refunded') {
                            $sms_admin_message =  $smsbox_config['admin_message_refunded'];
                        }
                        elseif($order->get_status() == 'failed') {
                            $sms_admin_message =  $smsbox_config['admin_message_failed'];
                        }

                        $admin_template = str_replace(array('[billing_first_name]','[billing_last_name]','[order_id]', '[order_status]', '[order_date]', '[payment_method]', '[payment_total]', '[product_id]', '[product_name]', '[product_qty]'), array($order->billing_first_name,$order->billing_last_name,$order->id, str_replace('wc-', '', $order->post_status), $order->order_date, $order->payment_method_title, html_entity_decode (strip_tags($order->get_formatted_order_total())), trim($product_id, ','), trim($product_name, ','), trim($product_qty, ',')), $sms_admin_message);
                        $to_admin = array();
                        $to_admin['type'] = 'admin';
                        $to_admin['to'] = $smsbox_config['admin_mobile'];
                        $to_admin['message'] = $admin_template;
                        $this->sendVsms($to_admin);
                    }
                }
            }
        }

        function sendVsms($sendArray = array()){
            global $woocommerce;
            $sender_id = get_option('wp_smsbox_config');

            $to = $sendArray['to'];
            $text = $sendArray['message'];
            $type = $sendArray['type'];

            $url  = 'http://www.smsbox.gr/httpapi/sendsms.php?username='.get_option('wp_smsbox_username').'&password='.get_option('wp_smsbox_password').'&to='.$to.'&from='.esc_html($sender_id['sender_id_'.$type]).'&text='.urlencode(substr($text,0,612)).'&encoding=UTF8';

            $ch = curl_init();
            curl_setopt($ch, CURLOPT_URL, $url);
            curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
            $result = curl_exec($ch);
            curl_close($ch);
        }
    }
    $m_Smsbox =  new Smsbox_config();
}
